from .exceptions import InvalidSettingsError  # noqa  # type: ignore
from .exceptions import NoConfigFile  # noqa  # type: ignore
from .settings import find_configuration_file  # noqa  # type: ignore
from .settings import get_config  # noqa  # type: ignore



__all__ = ["importlib_metadata"]

import sys

if sys.version_info >= (3, 10):  # pragma: no cover
    from importlib import metadata as importlib_metadata
else:  # pragma: no cover
    import importlib_metadata
